@@ -25,14 +25,14 @@ class DeleteBodyDbRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'facebody', '2019-12-30', 'DeleteBodyDb','facebody')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Id(self):
+	def get_Id(self): # Long
 		return self.get_body_params().get('Id')
 
-	def set_Id(self,Id):
-		self.add_body_params('Id', Id)
\ No newline at end of file
+	def set_Id(self, Id):  # Long
+		self.add_body_params('Id', Id)
