@@ -25,32 +25,39 @@ class SearchFaceRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'facebody', '2019-12-30', 'SearchFace','facebody')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_MaxFaceNum(self): # Long
+		return self.get_body_params().get('MaxFaceNum')
 
-	def get_Limit(self):
+	def set_MaxFaceNum(self, MaxFaceNum):  # Long
+		self.add_body_params('MaxFaceNum', MaxFaceNum)
+	def get_QualityScoreThreshold(self): # Float
+		return self.get_body_params().get('QualityScoreThreshold')
+
+	def set_QualityScoreThreshold(self, QualityScoreThreshold):  # Float
+		self.add_body_params('QualityScoreThreshold', QualityScoreThreshold)
+	def get_Limit(self): # Integer
 		return self.get_body_params().get('Limit')
 
-	def set_Limit(self,Limit):
+	def set_Limit(self, Limit):  # Integer
 		self.add_body_params('Limit', Limit)
+	def get_DbNames(self): # String
+		return self.get_body_params().get('DbNames')
 
-	def get_DbNames(self):
-		return self.get_query_params().get('DbNames')
-
-	def set_DbNames(self,DbNames):
-		self.add_query_param('DbNames',DbNames)
-
-	def get_DbName(self):
+	def set_DbNames(self, DbNames):  # String
+		self.add_body_params('DbNames', DbNames)
+	def get_DbName(self): # String
 		return self.get_body_params().get('DbName')
 
-	def set_DbName(self,DbName):
+	def set_DbName(self, DbName):  # String
 		self.add_body_params('DbName', DbName)
-
-	def get_ImageUrl(self):
+	def get_ImageUrl(self): # String
 		return self.get_body_params().get('ImageUrl')
 
-	def set_ImageUrl(self,ImageUrl):
-		self.add_body_params('ImageUrl', ImageUrl)
\ No newline at end of file
+	def set_ImageUrl(self, ImageUrl):  # String
+		self.add_body_params('ImageUrl', ImageUrl)
